@@ -7,11 +7,10 @@ use std::panic::{RefUnwindSafe, UnwindSafe};
 use std::sync::atomic::{AtomicUsize, Ordering};
 use std::sync::Arc;
 use std::sync::{LockResult, PoisonError, TryLockError, TryLockResult};
+use crossbeam::queue::SegQueue;
 
 use crate::cancel::trigger_cancel_panic;
 use crate::park::ParkError;
-use crate::std::queue::mpsc_list::Queue as WaitList;
-
 use super::blocking::SyncBlocker;
 use super::mutex::{self, Mutex};
 use super::poison;
@@ -23,7 +22,7 @@ pub struct RwLock<T: ?Sized> {
     // below two variables consist a global mutex
     // we need to deal with the cancel logic differently
     // the waiting blocker list
-    to_wake: WaitList<Arc<SyncBlocker>>,
+    to_wake: SegQueue<Arc<SyncBlocker>>,
     // track how many blockers are waiting on the mutex
     cnt: AtomicUsize,
 
@@ -57,7 +56,7 @@ pub struct RwLockWriteGuard<'a, T: ?Sized + 'a> {
 impl<T> RwLock<T> {
     pub fn new(t: T) -> RwLock<T> {
         RwLock {
-            to_wake: WaitList::new(),
+            to_wake: SegQueue::new(),
             cnt: AtomicUsize::new(0),
             rlock: Mutex::new(0),
             poison: poison::Flag::new(),
